@@ -378,9 +378,9 @@ def rz2rho(eqsf, r_in, z_in, t_in=None, coord_out='rho_pol', extrapolate=True):
         raise Exception('Wrong shape of r_in or z_in')
     
     if np.size(r_in,0) != nt_in:
-        raise Exception('Wrong shape of r_in %s'%str(r_in.shape))
+        raise Exception('Wrong shape of r_in %s, nt=%d' %(str(r_in.shape), nt_in))
     if np.size(z_in,0) != nt_in:
-        raise Exception('Wrong shape of z_in %s'%str(z_in.shape))
+        raise Exception('Wrong shape of z_in %s, nt=%d' %(str(z_in.shape), nt_in))
     if np.shape(r_in) != np.shape(z_in):
         raise Exception( 'Not equal shape of z_in and r_in %s,%s'\
                         %(str(z_in.shape), str(z_in.shape)) )
